@@ -32,11 +32,10 @@ void DataPtr::GenBoundaryCheck(Output* out_cc, Env* env, const char* data_size,
     ASSERT(id_);
 
     out_cc->println("// Checking out-of-bound for \"%s\"", data_name);
-    out_cc->println("if ( %s + (%s) > %s || %s + (%s) < %s )", ptr_expr(), data_size, env->RValue(end_of_data),
+    out_cc->println("if ( %s + (%s) > %s || %s + (%s) < %s ) {", ptr_expr(), data_size, env->RValue(end_of_data),
                     ptr_expr(), data_size, ptr_expr());
 
     out_cc->inc_indent();
-    out_cc->println("{");
 
     char* data_offset = AbsOffsetExpr(env, begin_of_data);
 
@@ -47,6 +46,6 @@ void DataPtr::GenBoundaryCheck(Output* out_cc, Env* env, const char* data_size,
 
     delete[] data_offset;
 
-    out_cc->println("}");
     out_cc->dec_indent();
+    out_cc->println("}");
 }
