@@ -1,8 +1,7 @@
-// Copyright (c) 2020-2023 by the Zeek Project. See LICENSE for details.
+// Copyright (c) 2020-now by the Zeek Project. See LICENSE for details.
 
 #pragma once
 
-#include <memory>
 #include <string>
 #include <utility>
 
@@ -20,7 +19,7 @@ public:
 
     node::Properties properties() const final {
         auto p = node::Properties{{"value", _value}};
-        return Ctor::properties() + p;
+        return Ctor::properties() + std::move(p);
     }
 
     static auto create(ASTContext* ctx, std::string v, const Meta& meta = {}) {
