@@ -1,8 +1,7 @@
-// Copyright (c) 2020-2023 by the Zeek Project. See LICENSE for details.
+// Copyright (c) 2020-now by the Zeek Project. See LICENSE for details.
 
 #pragma once
 
-#include <memory>
 #include <utility>
 
 #include <hilti/ast/expression.h>
@@ -21,7 +20,7 @@ public:
 
     node::Properties properties() const final {
         auto p = node::Properties{{"id", _id}};
-        return Expression::properties() + p;
+        return Expression::properties() + std::move(p);
     }
 
     static auto create(ASTContext* ctx, QualifiedType* member_type, const hilti::ID& id, Meta meta = {}) {
