@@ -57,7 +57,7 @@ public:
      *
      * @param op unresolved operator to match against
      * @returns tuple where the 1st element is a boolean indicating if the
-     * caller should proceed checking the candidates returned as the 2dn
+     * caller should proceed checking the candidates returned as the 2nd
      * element; if not, a match has been found but is valid for calling, and
      * hence the caller should abort resolution
      */
@@ -120,7 +120,7 @@ private:
  * operator available under that name.
  */
 inline auto get(std::string_view name) {
-    if ( auto op = Registry::singleton().byName(name) )
+    if ( const auto* op = Registry::singleton().byName(name) )
         return op;
     else
         logger().internalError(util::fmt("unknown operator '%s'", name));
