@@ -27,7 +27,7 @@ node::Set<declaration::Property> declaration::Module::moduleProperties(const ID&
     node::Set<declaration::Property> props;
 
     for ( const auto& d : declarations() ) {
-        if ( auto p = d->tryAs<declaration::Property>(); p && (! id || p->id() == id) )
+        if ( auto* p = d->tryAs<declaration::Property>(); p && (! id || p->id() == id) )
             props.push_back(p);
     }
 
