@@ -2,19 +2,12 @@
 individual settings via command-line arguments, environment variables, and
 files.
 """
+
 import os
-import sys
 import tempfile
 import unittest
 
-TESTS = os.path.dirname(os.path.realpath(__file__))
-ROOT = os.path.normpath(os.path.join(TESTS, ".."))
-
-# Prepend the tree's root folder to the module searchpath so we find zeekclient
-# via it. This allows tests to run without package installation.
-sys.path.insert(0, ROOT)
-
-import zeekclient  # pylint: disable=wrong-import-position
+import zeekclient
 
 
 class TestConfig(unittest.TestCase):
@@ -25,7 +18,8 @@ class TestConfig(unittest.TestCase):
         # One of each type:
         self.assertEqual(self.config.getint("client", "request_timeout_secs"), 20)
         self.assertEqual(
-            self.config.getfloat("client", "peering_retry_delay_secs"), 1.0
+            self.config.getfloat("client", "peering_retry_delay_secs"),
+            1.0,
         )
         self.assertEqual(self.config.getboolean("client", "rich_logging_format"), False)
 
@@ -39,7 +33,7 @@ class TestConfig(unittest.TestCase):
     @unittest.mock.patch.dict(
         os.environ,
         {
-            "ZEEK_CLIENT_CONFIG_SETTINGS": 'client.request_timeout_secs=23 server.FOO="1 2 3"'
+            "ZEEK_CLIENT_CONFIG_SETTINGS": 'client.request_timeout_secs=23 server.FOO="1 2 3"',
         },
     )
     def test_update_from_env(self):
@@ -50,7 +44,7 @@ class TestConfig(unittest.TestCase):
     def test_update_from_args(self):
         parser = zeekclient.cli.create_parser()
         args = parser.parse_args(
-            ["--set", "client.request_timeout_secs=42", "--set", "server.FOO=1 2 3"]
+            ["--set", "client.request_timeout_secs=42", "--set", "server.FOO=1 2 3"],
         )
         self.config.update_from_args(args)
         self.assertEqual(self.config.getint("client", "request_timeout_secs"), 42)
@@ -69,6 +63,30 @@ class TestConfig(unittest.TestCase):
         self.assertEqual(self.config.get("controller", "host"), "foo")
         self.assertEqual(self.config.getint("controller", "port"), 2149)
 
+        parser = zeekclient.cli.create_parser()
+        args = parser.parse_args(["--controller", "127.0.0.1"])
+        self.config.update_from_args(args)
+        self.assertEqual(self.config.get("controller", "host"), "127.0.0.1")
+        self.assertEqual(self.config.getint("controller", "port"), 2149)
+
+        parser = zeekclient.cli.create_parser()
+        args = parser.parse_args(["--controller", "127.0.0.1:"])
+        self.config.update_from_args(args)
+        self.assertEqual(self.config.get("controller", "host"), "127.0.0.1")
+        self.assertEqual(self.config.getint("controller", "port"), 2149)
+
+        parser = zeekclient.cli.create_parser()
+        args = parser.parse_args(["--controller", "[fe80::1]"])
+        self.config.update_from_args(args)
+        self.assertEqual(self.config.get("controller", "host"), "[fe80::1]")
+        self.assertEqual(self.config.getint("controller", "port"), 2149)
+
+        parser = zeekclient.cli.create_parser()
+        args = parser.parse_args(["--controller", "[fe80::1]:"])
+        self.config.update_from_args(args)
+        self.assertEqual(self.config.get("controller", "host"), "[fe80::1]")
+        self.assertEqual(self.config.getint("controller", "port"), 2149)
+
     def test_update_from_args_controller_port(self):
         parser = zeekclient.cli.create_parser()
         args = parser.parse_args(["--controller", ":2222"])
@@ -82,3 +100,15 @@ class TestConfig(unittest.TestCase):
         self.config.update_from_args(args)
         self.assertEqual(self.config.get("controller", "host"), "foo")
         self.assertEqual(self.config.getint("controller", "port"), 2222)
+
+        parser = zeekclient.cli.create_parser()
+        args = parser.parse_args(["--controller", "127.0.0.1:2222"])
+        self.config.update_from_args(args)
+        self.assertEqual(self.config.get("controller", "host"), "127.0.0.1")
+        self.assertEqual(self.config.getint("controller", "port"), 2222)
+
+        parser = zeekclient.cli.create_parser()
+        args = parser.parse_args(["--controller", "[fe80::1]:2222"])
+        self.config.update_from_args(args)
+        self.assertEqual(self.config.get("controller", "host"), "[fe80::1]")
+        self.assertEqual(self.config.getint("controller", "port"), 2222)
