@@ -2,8 +2,6 @@
 
 #include "zeek/Var.h"
 
-#include "zeek/zeek-config.h"
-
 #include <memory>
 
 #include "zeek/Desc.h"
@@ -18,7 +16,6 @@
 #include "zeek/Stmt.h"
 #include "zeek/Traverse.h"
 #include "zeek/Val.h"
-#include "zeek/module_util.h"
 #include "zeek/script_opt/IDOptInfo.h"
 #include "zeek/script_opt/ScriptOpt.h"
 #include "zeek/script_opt/StmtOptInfo.h"
@@ -145,7 +142,7 @@ static ExprPtr initialize_var(const IDPtr& id, InitClass c, ExprPtr init) {
     ExprPtr assignment;
 
     if ( c == INIT_FULL )
-        assignment = make_intrusive<AssignExpr>(lhs, init, false);
+        assignment = make_intrusive<AssignExpr>(lhs, init, false, nullptr, id->GetAttrs());
     else if ( c == INIT_EXTRA )
         assignment = make_intrusive<AddToExpr>(lhs, init);
     else if ( c == INIT_REMOVE )
@@ -206,6 +203,7 @@ static void make_var(const IDPtr& id, TypePtr t, InitClass c, ExprPtr init, std:
     }
 
     if ( id->GetType() && id->GetType()->Tag() != TYPE_ERROR && ! id->IsBlank() ) {
+        // NOLINTNEXTLINE(bugprone-assignment-in-if-condition)
         if ( dt != VAR_REDEF && (! init || ! do_init || (! t && ! (t = init_type(init)))) ) {
             id->Error("already defined", init.get());
             return;
@@ -440,9 +438,9 @@ static Attr* find_attr(const std::vector<AttrPtr>* al, AttrTag tag) {
     if ( ! al )
         return nullptr;
 
-    for ( size_t i = 0; i < al->size(); ++i )
-        if ( (*al)[i]->Tag() == tag )
-            return (*al)[i].get();
+    for ( const auto& attr : *al )
+        if ( attr->Tag() == tag )
+            return attr.get();
 
     return nullptr;
 }
@@ -469,7 +467,7 @@ static std::optional<FuncType::Prototype> func_type_check(const FuncType* decl,
                 auto msg = ad->DeprecationMessage();
 
                 if ( ! msg.empty() )
-                    msg = ": " + msg;
+                    msg = std::string{": "}.append(msg);
 
                 reporter->Deprecation(util::fmt("use of deprecated parameter '%s'%s (%s)", rval->args->FieldName(i),
                                                 msg.data(), obj_desc_short(impl).c_str()),
@@ -752,6 +750,7 @@ void end_func(StmtPtr body, const char* module_name, bool free_of_conditionals)
     // Note: ideally, something would take ownership of this memory until the
     // end of script execution, but that's essentially the same as the
     // lifetime of the process at the moment, so ok to "leak" it.
+    // NOLINTNEXTLINE(bugprone-unused-return-value)
     ingredients.release();
 }
 
