@@ -2,8 +2,6 @@
 
 #include "zeek/analyzer/protocol/dns/DNS.h"
 
-#include "zeek/zeek-config.h"
-
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
@@ -13,10 +11,37 @@
 #include "zeek/Event.h"
 #include "zeek/NetVar.h"
 #include "zeek/RunState.h"
+#include "zeek/Val.h"
 #include "zeek/ZeekString.h"
 #include "zeek/analyzer/protocol/dns/events.bif.h"
 #include "zeek/session/Manager.h"
 
+namespace {
+zeek::StringValPtr extract_char_string(zeek::analyzer::Analyzer* analyzer, const u_char*& data, int& len, int& rdlen) {
+    if ( rdlen <= 0 )
+        return nullptr;
+
+    uint8_t str_size = data[0];
+
+    --rdlen;
+    --len;
+    ++data;
+
+    if ( str_size > rdlen ) {
+        analyzer->Weird("DNS_TXT_char_str_past_rdlen");
+        return nullptr;
+    }
+
+    auto rval = zeek::make_intrusive<zeek::StringVal>(str_size, reinterpret_cast<const char*>(data));
+
+    rdlen -= str_size;
+    len -= str_size;
+    data += str_size;
+
+    return rval;
+}
+} // namespace
+
 namespace zeek::analyzer::dns {
 
 namespace detail {
@@ -275,6 +300,8 @@ bool DNS_Interpreter::ParseAnswer(detail::DNS_MsgInfo* msg, const u_char*& data,
 
             break;
 
+        case detail::TYPE_NAPTR: status = ParseRR_NAPTR(msg, data, len, rdlength, msg_start); break;
+
         case detail::TYPE_EDNS: status = ParseRR_EDNS(msg, data, len, rdlength, msg_start); break;
 
         case detail::TYPE_TKEY: status = ParseRR_TKEY(msg, data, len, rdlength, msg_start); break;
@@ -604,6 +631,50 @@ bool DNS_Interpreter::ParseRR_SRV(detail::DNS_MsgInfo* msg, const u_char*& data,
     return true;
 }
 
+bool DNS_Interpreter::ParseRR_NAPTR(detail::DNS_MsgInfo* msg, const u_char*& data, int& len, int rdlength,
+                                    const u_char* msg_start) {
+    zeek_uint_t order = ExtractShort(data, len);
+    zeek_uint_t preference = ExtractShort(data, len);
+    rdlength -= 4;
+
+    if ( len <= 0 || rdlength <= 0 ) {
+        analyzer->AnalyzerViolation("DNS_NAPTR_too_short");
+        return false;
+    }
+
+    // These all check rdlength and return nullptr if there's not enough data available.
+    auto flags = extract_char_string(analyzer, data, len, rdlength);
+    auto service = extract_char_string(analyzer, data, len, rdlength);
+    auto regexp = extract_char_string(analyzer, data, len, rdlength);
+
+    // The replacement string is a name. Compression shouldn't be used, but doesn't seem
+    // we have a helper that would allow to control this.
+    u_char replacement[513];
+    int replacement_len = sizeof(replacement) - 1;
+    u_char* replacement_end = ExtractName(data, len, replacement, replacement_len, msg_start, false);
+
+    if ( ! flags || ! service || ! regexp || ! replacement_end ) {
+        analyzer->AnalyzerViolation("DNS_NAPTR_RR_too_short");
+        return false;
+    }
+
+    if ( dns_NAPTR_reply && ! msg->skip_event ) {
+        static auto dns_naptr_rr = id::find_type<RecordType>("dns_naptr_rr");
+        auto r = make_intrusive<RecordVal>(dns_naptr_rr);
+
+        r->Assign(0, order);
+        r->Assign(1, preference);
+        r->Assign(2, std::move(flags));
+        r->Assign(3, std::move(service));
+        r->Assign(4, std::move(regexp));
+        r->Assign(5, zeek::make_intrusive<StringVal>(new String(replacement, replacement_end - replacement, true)));
+
+        analyzer->EnqueueConnEvent(dns_NAPTR_reply, analyzer->ConnVal(), msg->BuildHdrVal(), msg->BuildAnswerVal(), r);
+    }
+
+    return true;
+}
+
 bool DNS_Interpreter::ParseRR_EDNS(detail::DNS_MsgInfo* msg, const u_char*& data, int& len, int rdlength,
                                    const u_char* msg_start) {
     if ( dns_EDNS_addl && ! msg->skip_event )
@@ -701,8 +772,8 @@ bool DNS_Interpreter::ParseRR_EDNS(detail::DNS_MsgInfo* msg, const u_char*& data
                         bits_left -= 8;
                     }
 
-                    for ( uint8_t i = 0; i < 4; i++ ) {
-                        addr[i] = htonl(addr[i]);
+                    for ( uint32_t& a : addr ) {
+                        a = htonl(a);
                     }
                     opt.ecs_addr = make_intrusive<AddrVal>(addr);
                 }
@@ -792,7 +863,7 @@ bool DNS_Interpreter::ParseRR_EDNS(detail::DNS_MsgInfo* msg, const u_char*& data
 
 void DNS_Interpreter::ExtractOctets(const u_char*& data, int& len, String** p) {
     uint16_t dlen = ExtractShort(data, len);
-    dlen = min(len, static_cast<int>(dlen));
+    dlen = std::min(len, static_cast<int>(dlen));
 
     if ( p )
         *p = new String(data, dlen, false);
@@ -802,8 +873,8 @@ void DNS_Interpreter::ExtractOctets(const u_char*& data, int& len, String** p) {
 }
 
 String* DNS_Interpreter::ExtractStream(const u_char*& data, int& len, int l) {
-    l = max(l, 0);
-    int dlen = min(len, l); // Len in bytes of the algorithm use
+    l = std::max(l, 0);
+    int dlen = std::min(len, l); // Len in bytes of the algorithm use
     auto rval = new String(data, dlen, false);
 
     data += dlen;
@@ -926,18 +997,18 @@ bool DNS_Interpreter::ParseRR_RRSIG(detail::DNS_MsgInfo* msg, const u_char*& dat
 
     switch ( dsa ) {
         case detail::RSA_MD5: analyzer->Weird("DNSSEC_RRSIG_NotRecommended_ZoneSignAlgo", util::fmt("%d", algo)); break;
-        case detail::Diffie_Hellman: break;
-        case detail::DSA_SHA1: break;
-        case detail::Elliptic_Curve: break;
-        case detail::RSA_SHA1: break;
-        case detail::DSA_NSEC3_SHA1: break;
-        case detail::RSA_SHA1_NSEC3_SHA1: break;
-        case detail::RSA_SHA256: break;
-        case detail::RSA_SHA512: break;
-        case detail::GOST_R_34_10_2001: break;
-        case detail::ECDSA_curveP256withSHA256: break;
-        case detail::ECDSA_curveP384withSHA384: break;
-        case detail::Ed25519: break;
+        case detail::Diffie_Hellman:
+        case detail::DSA_SHA1:
+        case detail::Elliptic_Curve:
+        case detail::RSA_SHA1:
+        case detail::DSA_NSEC3_SHA1:
+        case detail::RSA_SHA1_NSEC3_SHA1:
+        case detail::RSA_SHA256:
+        case detail::RSA_SHA512:
+        case detail::GOST_R_34_10_2001:
+        case detail::ECDSA_curveP256withSHA256:
+        case detail::ECDSA_curveP384withSHA384:
+        case detail::Ed25519:
         case detail::Ed448: break;
         case detail::Indirect: analyzer->Weird("DNSSEC_RRSIG_Indirect_ZoneSignAlgo", util::fmt("%d", algo)); break;
         case detail::PrivateDNS: analyzer->Weird("DNSSEC_RRSIG_PrivateDNS_ZoneSignAlgo", util::fmt("%d", algo)); break;
@@ -1001,18 +1072,18 @@ bool DNS_Interpreter::ParseRR_DNSKEY(detail::DNS_MsgInfo* msg, const u_char*& da
         case detail::RSA_MD5:
             analyzer->Weird("DNSSEC_DNSKEY_NotRecommended_ZoneSignAlgo", util::fmt("%d", dalgorithm));
             break;
-        case detail::Diffie_Hellman: break;
-        case detail::DSA_SHA1: break;
-        case detail::Elliptic_Curve: break;
-        case detail::RSA_SHA1: break;
-        case detail::DSA_NSEC3_SHA1: break;
-        case detail::RSA_SHA1_NSEC3_SHA1: break;
-        case detail::RSA_SHA256: break;
-        case detail::RSA_SHA512: break;
-        case detail::GOST_R_34_10_2001: break;
-        case detail::ECDSA_curveP256withSHA256: break;
-        case detail::ECDSA_curveP384withSHA384: break;
-        case detail::Ed25519: break;
+        case detail::Diffie_Hellman:
+        case detail::DSA_SHA1:
+        case detail::Elliptic_Curve:
+        case detail::RSA_SHA1:
+        case detail::DSA_NSEC3_SHA1:
+        case detail::RSA_SHA1_NSEC3_SHA1:
+        case detail::RSA_SHA256:
+        case detail::RSA_SHA512:
+        case detail::GOST_R_34_10_2001:
+        case detail::ECDSA_curveP256withSHA256:
+        case detail::ECDSA_curveP384withSHA384:
+        case detail::Ed25519:
         case detail::Ed448: break;
         case detail::Indirect:
             analyzer->Weird("DNSSEC_DNSKEY_Indirect_ZoneSignAlgo", util::fmt("%d", dalgorithm));
@@ -1218,9 +1289,9 @@ bool DNS_Interpreter::ParseRR_DS(detail::DNS_MsgInfo* msg, const u_char*& data,
     String* ds_digest = ExtractStream(data, len, rdlength - 4);
 
     switch ( ds_digest_type ) {
-        case detail::SHA1: break;
-        case detail::SHA256: break;
-        case detail::GOST_R_34_11_94: break;
+        case detail::SHA1:
+        case detail::SHA256:
+        case detail::GOST_R_34_11_94:
         case detail::SHA384: break;
         case detail::reserved: analyzer->Weird("DNSSEC_DS_ReservedDigestType", util::fmt("%d", ds_dtype)); break;
         default: analyzer->Weird("DNSSEC_DS_unknown_DigestType", util::fmt("%d", ds_dtype)); break;
@@ -1374,7 +1445,9 @@ bool DNS_Interpreter::ParseRR_A(detail::DNS_MsgInfo* msg, const u_char*& data, i
 bool DNS_Interpreter::ParseRR_AAAA(detail::DNS_MsgInfo* msg, const u_char*& data, int& len, int rdlength) {
     uint32_t addr[4];
 
-    for ( int i = 0; i < 4; ++i ) {
+    // Intentionally leaving this as a normal loop because it's more descriptive.
+    // NOLINTNEXTLINE(modernize-loop-convert)
+    for ( size_t i = 0; i < 4; i++ ) {
         addr[i] = htonl(ExtractLong(data, len));
 
         if ( len < 0 ) {
@@ -1413,30 +1486,6 @@ bool DNS_Interpreter::ParseRR_WKS(detail::DNS_MsgInfo* msg, const u_char*& data,
     return true;
 }
 
-static StringValPtr extract_char_string(analyzer::Analyzer* analyzer, const u_char*& data, int& len, int& rdlen) {
-    if ( rdlen <= 0 )
-        return nullptr;
-
-    uint8_t str_size = data[0];
-
-    --rdlen;
-    --len;
-    ++data;
-
-    if ( str_size > rdlen ) {
-        analyzer->Weird("DNS_TXT_char_str_past_rdlen");
-        return nullptr;
-    }
-
-    auto rval = make_intrusive<StringVal>(str_size, reinterpret_cast<const char*>(data));
-
-    rdlen -= str_size;
-    len -= str_size;
-    data += str_size;
-
-    return rval;
-}
-
 bool DNS_Interpreter::ParseRR_HINFO(detail::DNS_MsgInfo* msg, const u_char*& data, int& len, int rdlength) {
     if ( ! dns_HINFO_reply || msg->skip_event ) {
         data += rdlength;
@@ -1688,7 +1737,7 @@ RecordValPtr DNS_MsgInfo::BuildEDNS_Val() {
     // unsigned int DO = ttl & 0x8000;	// "DNSSEC OK" - RFC 3225
     unsigned int z = ttl & 0xffff;
 
-    unsigned int return_error = (ercode << 8) | rcode;
+    unsigned int return_error = (ercode << 4) | rcode;
 
     r->Assign(4, return_error);
     r->Assign(5, version);
