@@ -2,11 +2,8 @@
 
 #include "zeek/analyzer/protocol/http/HTTP.h"
 
-#include "zeek/zeek-config.h"
-
 #include <algorithm>
 #include <cctype>
-#include <cmath>
 #include <cstdlib>
 #include <string>
 
@@ -23,14 +20,14 @@ const bool DEBUG_http = false;
 
 // The EXPECT_*_NOTHING states are used to prevent further parsing. Used if a
 // message was interrupted.
-enum HTTP_ExpectRequest {
+enum HTTP_ExpectRequest : uint8_t {
     EXPECT_REQUEST_LINE,
     EXPECT_REQUEST_MESSAGE,
     EXPECT_REQUEST_TRAILER,
     EXPECT_REQUEST_NOTHING,
 };
 
-enum HTTP_ExpectReply {
+enum HTTP_ExpectReply : uint8_t {
     EXPECT_REPLY_LINE,
     EXPECT_REPLY_MESSAGE,
     EXPECT_REPLY_TRAILER,
@@ -106,7 +103,7 @@ void HTTP_Entity::Deliver(int len, const char* data, bool trailing_CRLF) {
     // Entity body.
     if ( content_type == analyzer::mime::CONTENT_TYPE_MULTIPART ||
          content_type == analyzer::mime::CONTENT_TYPE_MESSAGE )
-        DeliverBody(len, data, trailing_CRLF);
+        DeliverBody(len, data, trailing_CRLF); // NOLINT(bugprone-branch-clone)
 
     else if ( chunked_transfer_state != NON_CHUNKED_TRANSFER ) {
         switch ( chunked_transfer_state ) {
@@ -346,10 +343,10 @@ void HTTP_Entity::SubmitHeader(analyzer::mime::MIME_Header* h) {
     else if ( analyzer::mime::istrequal(h->get_name(), "content-range") &&
               http_message->MyHTTP_Analyzer()->HTTP_ReplyCode() == 206 ) {
         data_chunk_t vt = h->get_value_token();
-        string byte_unit(vt.data, vt.length);
+        std::string byte_unit(vt.data, vt.length);
         vt = h->get_value_after_token();
-        string byte_range(vt.data, vt.length);
-        byte_range.erase(remove(byte_range.begin(), byte_range.end(), ' '), byte_range.end());
+        std::string byte_range(vt.data, vt.length);
+        byte_range.erase(std::ranges::begin(std::ranges::remove(byte_range, ' ')), std::end(byte_range));
 
         if ( byte_unit != "bytes" ) {
             http_message->Weird("HTTP_content_range_unknown_byte_unit");
@@ -357,28 +354,29 @@ void HTTP_Entity::SubmitHeader(analyzer::mime::MIME_Header* h) {
         }
 
         size_t p = byte_range.find('/');
-        if ( p == string::npos ) {
+        if ( p == std::string::npos ) {
             http_message->Weird("HTTP_content_range_cannot_parse");
             return;
         }
 
-        string byte_range_resp_spec = byte_range.substr(0, p);
-        string instance_length_str = byte_range.substr(p + 1);
+        std::string byte_range_resp_spec = byte_range.substr(0, p);
+        std::string instance_length_str = byte_range.substr(p + 1);
 
         p = byte_range_resp_spec.find('-');
-        if ( p == string::npos ) {
+        if ( p == std::string::npos ) {
             http_message->Weird("HTTP_content_range_cannot_parse");
             return;
         }
 
-        string first_byte_pos = byte_range_resp_spec.substr(0, p);
-        string last_byte_pos = byte_range_resp_spec.substr(p + 1);
+        std::string first_byte_pos = byte_range_resp_spec.substr(0, p);
+        std::string last_byte_pos = byte_range_resp_spec.substr(p + 1);
 
         if ( DEBUG_http )
             DEBUG_MSG("Parsed Content-Range: %s %s-%s/%s\n", byte_unit.c_str(), first_byte_pos.c_str(),
                       last_byte_pos.c_str(), instance_length_str.c_str());
 
-        int64_t f, l;
+        int64_t f;
+        int64_t l;
         int fr = util::atoi_n(first_byte_pos.size(), first_byte_pos.c_str(), nullptr, 10, f);
         int lr = util::atoi_n(last_byte_pos.size(), last_byte_pos.c_str(), nullptr, 10, l);
         if ( fr != 1 || lr != 1 ) {
@@ -1114,7 +1112,7 @@ const char* HTTP_Analyzer::PrefixMatch(const char* line, const char* end_of_line
 
 const char* HTTP_Analyzer::PrefixWordMatch(const char* line, const char* end_of_line, const char* prefix,
                                            bool ignore_case) {
-    if ( (line = PrefixMatch(line, end_of_line, prefix, ignore_case)) == nullptr )
+    if ( line = PrefixMatch(line, end_of_line, prefix, ignore_case); line == nullptr )
         return nullptr;
 
     const char* orig_line = line;
@@ -1420,7 +1418,7 @@ void HTTP_Analyzer::HTTP_Upgrade() {
                 analyzer_tag_val->GetType<EnumType>()->Lookup(analyzer_tag_val->AsEnum()),
                 upgrade_protocol_val->CheckString());
         auto analyzer_tag = analyzer_mgr->GetComponentTag(analyzer_tag_val.get());
-        auto* analyzer = analyzer_mgr->InstantiateAnalyzer(std::move(analyzer_tag), Conn());
+        auto* analyzer = analyzer_mgr->InstantiateAnalyzer(analyzer_tag, Conn());
         if ( analyzer ) {
             AddChildAnalyzer(analyzer);
 
@@ -1634,11 +1632,11 @@ void HTTP_Analyzer::SkipEntityData(bool is_orig) {
 }
 
 bool is_reserved_URI_char(unsigned char ch) { // see RFC 3986 (definition of URI)
-    return strchr(":/?#[]@!$&'()*+,;=", ch) != 0;
+    return strchr(":/?#[]@!$&'()*+,;=", ch) != nullptr;
 }
 
 bool is_unreserved_URI_char(unsigned char ch) { // see RFC 3986 (definition of URI)
-    return isalnum(ch) != 0 || strchr("-_.!~*\'()", ch) != 0;
+    return isalnum(ch) != 0 || strchr("-_.!~*\'()", ch) != nullptr;
 }
 
 void escape_URI_char(unsigned char ch, unsigned char*& p) {
