@@ -1,8 +1,6 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "zeek/RE.h"
 #include "zeek/script_opt/CPP/Compile.h"
-#include "zeek/script_opt/ProfileFunc.h"
 
 namespace zeek::detail {
 
@@ -30,7 +28,7 @@ string CPPCompile::GenListExpr(const Expr* e, GenType gt, bool nested) {
 
         if ( nested && e_i->Tag() == EXPR_LIST )
             // These are table or set indices.
-            gen_i = string("index_val__CPP({") + gen_i + "})";
+            gen_i = util::fmt("index_val__CPP({%s})", gen_i.c_str());
 
         gen += gen_i;
 
@@ -143,7 +141,7 @@ string CPPCompile::GenExpr(const Expr* e, GenType gt, bool top_level) {
         default:
             // Intended to catch errors in overlooking the possible
             // expressions that might appear.
-            return string("EXPR");
+            return "EXPR";
     }
 }
 
@@ -827,7 +825,7 @@ string CPPCompile::GenVal(const ValPtr& v) {
     auto it = t->InternalType();
 
     if ( tag == TYPE_BOOL )
-        return string(v->IsZero() ? "false" : "true");
+        return v->IsZero() ? "false" : "true";
 
     if ( tag == TYPE_ENUM )
         return GenEnum(t, v);
@@ -1146,7 +1144,7 @@ string CPPCompile::GenListAssign(const ExprPtr& lhs, const ExprPtr& rhs) {
 }
 
 string CPPCompile::GenVectorOp(const Expr* e, string op, const char* vec_op) {
-    auto t = e->GetType();
+    const auto& t = e->GetType();
     auto gen_t = GenTypeName(t);
     auto gen = string("vec_op_") + vec_op + "__CPP(" + op + ", " + gen_t + ")";
 
@@ -1198,7 +1196,7 @@ string CPPCompile::GenLambdaClone(const LambdaExpr* l, bool all_deep) {
         if ( captures && ! IsNativeType(id_t) ) {
             for ( const auto& c : *captures )
                 if ( id == c.Id() && (c.IsDeepCopy() || all_deep) )
-                    arg = string("cast_intrusive<") + TypeName(id_t) + ">(" + arg + "->Clone())";
+                    arg = util::fmt("cast_intrusive<%s>(%s->Clone())", TypeName(id_t), arg.c_str());
         }
 
         cl_args += ", " + arg;
@@ -1243,7 +1241,6 @@ string CPPCompile::GenField(const ExprPtr& rec, int field) {
         auto pt = processed_types.find(rt);
         ASSERT(pt != processed_types.end());
         auto rt_offset = pt->second->Offset();
-        string field_name = rt->FieldName(field);
         field_decls.emplace_back(rt_offset, rt->FieldDecl(field));
 
         if ( rfm != record_field_mappings.end() )
