@@ -2,7 +2,7 @@
 
 #include "zeek/script_opt/FuncInfo.h"
 
-#include <unordered_set>
+#include <unordered_map>
 
 namespace zeek::detail {
 
@@ -20,29 +20,29 @@ namespace zeek::detail {
 // to the event engine.
 
 // Does not change script-level state (though may change internal state).
-#define ATTR_NO_SCRIPT_SIDE_EFFECTS 0x1
+constexpr unsigned int ATTR_NO_SCRIPT_SIDE_EFFECTS = 0x1;
 
 // Does not change any Zeek state, internal or external. (May change
 // state outside of Zeek, such as file system elements.) Implies
 // ATTR_NO_SCRIPT_SIDE_EFFECTS.
-#define ATTR_NO_ZEEK_SIDE_EFFECTS 0x2
+constexpr unsigned int ATTR_NO_ZEEK_SIDE_EFFECTS = 0x2;
 
 // Calls made with the same arguments yield the same results, if made
 // after full Zeek initialization. Implies ATTR_NO_ZEEK_SIDE_EFFECTS.
-#define ATTR_IDEMPOTENT 0x4
+constexpr unsigned int ATTR_IDEMPOTENT = 0x4;
 
 // Calls with constant arguments can always be folded, even prior to
 // full Zeek initialization. Such functions must not have the potential
 // to generate errors. Implies ATTR_IDEMPOTENT.
-#define ATTR_FOLDABLE 0x8
+constexpr unsigned int ATTR_FOLDABLE = 0x8;
 
 // The event engine knows about this script function and may call it
 // during its processing.
-#define ATTR_SPECIAL_SCRIPT_FUNC 0x10
+constexpr unsigned int ATTR_SPECIAL_SCRIPT_FUNC = 0x10;
 
 // ZAM knows about this script function and will replace it with specialized
 // instructions.
-#define ATTR_ZAM_REPLACEABLE_SCRIPT_FUNC 0x20
+constexpr unsigned int ATTR_ZAM_REPLACEABLE_SCRIPT_FUNC = 0x20;
 
 static std::unordered_map<std::string, unsigned int> func_attrs = {
     // Script functions.
@@ -79,6 +79,9 @@ static std::unordered_map<std::string, unsigned int> func_attrs = {
     {"Cluster::__unsubscribe", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Cluster::make_event", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Cluster::publish", ATTR_NO_SCRIPT_SIDE_EFFECTS},
+    {"EventMetadata::current", ATTR_NO_SCRIPT_SIDE_EFFECTS},
+    {"EventMetadata::current_all", ATTR_NO_SCRIPT_SIDE_EFFECTS},
+    {"EventMetadata::register", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"FileExtract::__set_limit", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Files::__add_analyzer", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Files::__analyzer_enabled", ATTR_NO_ZEEK_SIDE_EFFECTS},
@@ -114,6 +117,7 @@ static std::unordered_map<std::string, unsigned int> func_attrs = {
     {"Option::set_change_handler", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"PacketAnalyzer::GTPV1::remove_gtpv1_connection", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"PacketAnalyzer::Geneve::get_options", ATTR_NO_SCRIPT_SIDE_EFFECTS},
+    {"PacketAnalyzer::PPPoE::session_id", ATTR_NO_ZEEK_SIDE_EFFECTS},
     {"PacketAnalyzer::TEREDO::remove_teredo_connection", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"PacketAnalyzer::__disable_analyzer", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"PacketAnalyzer::__enable_analyzer", ATTR_NO_SCRIPT_SIDE_EFFECTS},
@@ -158,6 +162,7 @@ static std::unordered_map<std::string, unsigned int> func_attrs = {
     {"Storage::Sync::__get", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Storage::Sync::__open_backend", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Storage::Sync::__put", ATTR_NO_SCRIPT_SIDE_EFFECTS},
+    {"Storage::is_forced_sync", ATTR_NO_ZEEK_SIDE_EFFECTS},
     {"Supervisor::__create", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Supervisor::__destroy", ATTR_NO_SCRIPT_SIDE_EFFECTS},
     {"Supervisor::__is_supervised", ATTR_IDEMPOTENT},
@@ -263,6 +268,7 @@ static std::unordered_map<std::string, unsigned int> func_attrs = {
     {"find_all", ATTR_FOLDABLE},
     {"find_all_ordered", ATTR_FOLDABLE},
     {"find_entropy", ATTR_FOLDABLE},
+    {"find_first", ATTR_FOLDABLE},
     {"find_in_zeekpath", ATTR_IDEMPOTENT}, // can error
     {"find_last", ATTR_FOLDABLE},
     {"find_str", ATTR_FOLDABLE},
@@ -296,6 +302,7 @@ static std::unordered_map<std::string, unsigned int> func_attrs = {
     {"get_net_stats", ATTR_NO_ZEEK_SIDE_EFFECTS},
     {"get_orig_seq", ATTR_NO_ZEEK_SIDE_EFFECTS},
     {"get_package_readme", ATTR_FOLDABLE},
+    {"get_plugin_components", ATTR_NO_ZEEK_SIDE_EFFECTS},
     {"get_port_transport_proto", ATTR_FOLDABLE},
     {"get_proc_stats", ATTR_NO_ZEEK_SIDE_EFFECTS},
     {"get_reassembler_stats", ATTR_NO_ZEEK_SIDE_EFFECTS},
