@@ -12,9 +12,8 @@ namespace zeek::detail {
 
 const ZAMStmt ZAMCompiler::CompileStmt(const Stmt* s) {
     auto loc = s->GetLocationInfo();
-    ASSERT(loc->first_line != 0 || s->Tag() == STMT_NULL);
-    auto loc_copy =
-        std::make_shared<Location>(loc->filename, loc->first_line, loc->last_line, loc->first_column, loc->last_column);
+    ASSERT(loc->FirstLine() != 0 || s->Tag() == STMT_NULL);
+    auto loc_copy = std::make_shared<Location>(loc->FileName(), loc->FirstLine(), loc->LastLine());
     ASSERT(! AST_blocks || s->Tag() == STMT_NULL || AST_blocks->HaveExpDesc(loc_copy.get()));
     auto loc_parent = ZAM::curr_loc->Parent();
     ZAM::curr_loc = std::make_shared<ZAMLocInfo>(ZAM::curr_func, std::move(loc_copy), ZAM::curr_loc->Parent());
@@ -616,7 +615,7 @@ const ZAMStmt ZAMCompiler::TypeSwitch(const SwitchStmt* sw, const NameExpr* v, c
 }
 
 const ZAMStmt ZAMCompiler::CompileWhile(const WhileStmt* ws) {
-    auto loop_condition = ws->Condition();
+    const auto& loop_condition = ws->Condition();
 
     if ( loop_condition->Tag() == EXPR_CONST ) {
         if ( loop_condition->IsZero() )
@@ -1019,7 +1018,7 @@ const ZAMStmt ZAMCompiler::CompileWhen(const WhenStmt* ws) {
     aux->wi = wi;
 
     for ( auto i = 0; i < n; ++i ) {
-        auto la = local_aggr_slots[i];
+        const auto& la = local_aggr_slots[i];
         aux->Add(i, FrameSlot(la), la->GetType());
     }
 
@@ -1072,7 +1071,7 @@ const ZAMStmt ZAMCompiler::CompileAssert(const AssertStmt* as) {
     auto cond_desc = make_intrusive<StringVal>(new String(as->CondDesc()));
     auto cond_desc_e = make_intrusive<ConstExpr>(cond_desc);
 
-    if ( auto msg = as->Msg() ) {
+    if ( const auto& msg = as->Msg() ) {
         auto& msg_setup_stmt = as->MsgSetupStmt();
         if ( msg_setup_stmt )
             (void)CompileStmt(msg_setup_stmt);
