@@ -4,11 +4,9 @@
 
 #include <sys/types.h> // for u_char
 #include <unordered_map>
-#include <utility>
 
+#include "zeek/ConnKey.h"
 #include "zeek/Frag.h"
-#include "zeek/Hash.h"
-#include "zeek/NetVar.h"
 #include "zeek/session/Session.h"
 
 namespace zeek {
@@ -52,6 +50,7 @@ struct Stats {
     size_t num_fragments;
     size_t max_fragments;
     uint64_t num_packets;
+    uint64_t num_packets_unprocessed;
 };
 
 class Manager final {
@@ -73,7 +72,7 @@ public:
      * @param conn_key The key for the connection to search for.
      * @return The connection, or nullptr if one doesn't exist.
      */
-    Connection* FindConnection(const zeek::detail::ConnKey& conn_key);
+    Connection* FindConnection(const zeek::ConnKey& conn_key);
 
     void Remove(Session* s);
     void Insert(Session* c, bool remove_existing = true);
