@@ -24,10 +24,11 @@
 
 #include <hilti/autogen/config.h>
 
-#include <zeek/analyzer/Manager.h>
-#include <zeek/file_analysis/Manager.h>
-#include <zeek/packet_analysis/Manager.h>
-
+#include "zeek/Event.h"
+#include "zeek/analyzer/Manager.h"
+#include "zeek/file_analysis/Manager.h"
+#include "zeek/module_util.h"
+#include "zeek/packet_analysis/Manager.h"
 #include "zeek/spicy/file-analyzer.h"
 #include "zeek/spicy/packet-analyzer.h"
 #include "zeek/spicy/protocol-analyzer.h"
@@ -63,8 +64,9 @@ void Manager::registerSpicyModuleEnd() {
 void Manager::registerProtocolAnalyzer(const std::string& name, hilti::rt::Protocol proto,
                                        const hilti::rt::Vector<::zeek::spicy::rt::PortRange>& ports,
                                        const std::string& parser_orig, const std::string& parser_resp,
-                                       const std::string& replaces, const std::string& linker_scope) {
-    SPICY_DEBUG(hilti::rt::fmt("Have Spicy protocol analyzer %s", name));
+                                       const std::string& replaces,
+                                       const hilti::rt::integer::safe<uint64_t>& linker_scope) {
+    SPICY_DEBUG(hilti::rt::fmt("Have Spicy protocol analyzer %s (scope 0x%" PRIx64 ")", name, linker_scope.Ref()));
 
     ProtocolAnalyzerInfo info;
     info.name_analyzer = name;
@@ -78,8 +80,10 @@ void Manager::registerProtocolAnalyzer(const std::string& name, hilti::rt::Proto
 
     // Store ports in a deterministic order. We can't (easily) sort the
     // `hilti::rt::Vector` unfortunately.
-    std::copy(ports.begin(), ports.end(), std::back_inserter(info.ports));
-    std::sort(info.ports.begin(), info.ports.end());
+    std::ranges::copy(ports, std::back_inserter(info.ports));
+    std::ranges::sort(info.ports, [](const ::zeek::spicy::rt::PortRange& l, const ::zeek::spicy::rt::PortRange& r) {
+        return l < r;
+    });
 
     // We may have that analyzer already iff it was previously pre-registered
     // without a linker scope. We'll then only set the scope now.
@@ -124,8 +128,8 @@ void Manager::registerProtocolAnalyzer(const std::string& name, hilti::rt::Proto
 
 void Manager::registerFileAnalyzer(const std::string& name, const hilti::rt::Vector<std::string>& mime_types,
                                    const std::string& parser, const std::string& replaces,
-                                   const std::string& linker_scope) {
-    SPICY_DEBUG(hilti::rt::fmt("Have Spicy file analyzer %s", name));
+                                   const hilti::rt::integer::safe<uint64_t>& linker_scope) {
+    SPICY_DEBUG(hilti::rt::fmt("Have Spicy file analyzer %s (scope 0x%" PRIx64 ")", name, linker_scope.Ref()));
 
     FileAnalyzerInfo info;
     info.name_analyzer = name;
@@ -169,8 +173,8 @@ void Manager::registerFileAnalyzer(const std::string& name, const hilti::rt::Vec
 }
 
 void Manager::registerPacketAnalyzer(const std::string& name, const std::string& parser, const std::string& replaces,
-                                     const std::string& linker_scope) {
-    SPICY_DEBUG(hilti::rt::fmt("Have Spicy packet analyzer %s", name));
+                                     const hilti::rt::integer::safe<uint64_t>& linker_scope) {
+    SPICY_DEBUG(hilti::rt::fmt("Have Spicy packet analyzer %s (scope 0x%" PRIx64 ")", name, linker_scope.Ref()));
 
     PacketAnalyzerInfo info;
     info.name_analyzer = name;
@@ -353,7 +357,7 @@ bool Manager::toggleProtocolAnalyzer(const Tag& tag, bool enable) {
         analyzer_mgr->DisableAnalyzer(tag);
 
         if ( analyzer.replaces ) {
-            SPICY_DEBUG(hilti::rt::fmt("Re-enabling standard protocol analyzer %s", analyzer.name_analyzer));
+            SPICY_DEBUG(hilti::rt::fmt("Re-enabling standard protocol analyzer %s", analyzer.name_replaces));
             analyzer_mgr->EnableAnalyzer(analyzer.replaces);
         }
     }
@@ -487,16 +491,14 @@ static std::unique_ptr<detail::Location> _makeLocation(const std::string& locati
             return nullptr;
 
         auto loc = std::make_unique<detail::Location>();
-        loc->filename = filenames.insert(std::string(x[0])).first->c_str(); // we retain ownership
+        loc->SetFile(filenames.insert(std::string(x[0])).first->c_str()); // we retain ownership
 
         if ( x.size() >= 2 ) {
             auto y = hilti::rt::split(x[1], "-");
-            if ( y.size() >= 2 ) {
-                loc->first_line = std::stoi(std::string(y[0]));
-                loc->last_line = std::stoi(std::string(y[1]));
-            }
+            if ( y.size() >= 2 )
+                loc->SetLines(std::stoi(std::string(y[0])), std::stoi(std::string(y[1])));
             else if ( y[0].size() )
-                loc->first_line = loc->last_line = std::stoi(std::string(y[0]));
+                loc->SetLine(std::stoi(std::string(y[0])));
         }
 
         return loc;
@@ -531,7 +533,7 @@ void Manager::analyzerError(file_analysis::Analyzer* a, const std::string& msg,
     reporter->PopLocation();
 
     if ( a )
-        a->SetSkip(1); // Imitate what AnalyzerError() does for protocol analyzers.
+        a->SetSkip(true); // Imitate what AnalyzerError() does for protocol analyzers.
 }
 
 void Manager::analyzerError(packet_analysis::Analyzer* a, const std::string& msg, const std::string& location) {
@@ -635,26 +637,24 @@ void Manager::InitPostScript() {
     auto spicy_config = ::spicy::rt::configuration::get();
     spicy_config.hook_accept_input = hook_accept_input;
     spicy_config.hook_decline_input = hook_decline_input;
-    ::spicy::rt::configuration::set(std::move(spicy_config));
+    ::spicy::rt::configuration::set(spicy_config);
 
     try {
         ::hilti::rt::init();
         ::spicy::rt::init();
     } catch ( const hilti::rt::Exception& e ) {
-        std::cerr << hilti::rt::fmt("uncaught runtime exception %s during initialization: %s",
-                                    hilti::rt::demangle(typeid(e).name()), e.what())
-                  << std::endl;
+        std::cerr << hilti::rt::fmt("uncaught runtime exception %s during initialization: %s\n",
+                                    hilti::rt::demangle(typeid(e).name()), e.what());
         exit(1);
     } catch ( const std::runtime_error& e ) {
-        std::cerr << hilti::rt::fmt("uncaught C++ exception %s during initialization: %s",
-                                    hilti::rt::demangle(typeid(e).name()), e.what())
-                  << std::endl;
+        std::cerr << hilti::rt::fmt("uncaught C++ exception %s during initialization: %s\n",
+                                    hilti::rt::demangle(typeid(e).name()), e.what());
         exit(1);
     }
 
     // Fill in the parser information now that we derived from the ASTs.
     auto find_parser = [](const std::string& analyzer, const std::string& parser,
-                          const std::string& linker_scope) -> const ::spicy::rt::Parser* {
+                          const auto& linker_scope) -> const ::spicy::rt::Parser* {
         if ( parser.empty() )
             return nullptr;
 
@@ -663,8 +663,8 @@ void Manager::InitPostScript() {
                 return p;
         }
 
-        reporter->InternalError("Unknown Spicy parser '%s' requested by analyzer '%s'", parser.c_str(),
-                                analyzer.c_str());
+        reporter->InternalError("Unknown Spicy parser '%s' (scope 0x%" PRIx64 ") requested by analyzer '%s'",
+                                parser.c_str(), linker_scope.Ref(), analyzer.c_str());
 
         return nullptr; // cannot be reached
     };
@@ -674,7 +674,8 @@ void Manager::InitPostScript() {
             // vector element not set
             continue;
 
-        SPICY_DEBUG(hilti::rt::fmt("Registering %s protocol analyzer %s with Zeek", p.protocol, p.name_analyzer));
+        SPICY_DEBUG(hilti::rt::fmt("Registering %s protocol analyzer %s (scope 0x%" PRIx64 ") with Zeek", p.protocol,
+                                   p.name_analyzer, p.linker_scope));
 
         p.parser_orig = find_parser(p.name_analyzer, p.name_parser_orig, p.linker_scope);
         p.parser_resp = find_parser(p.name_analyzer, p.name_parser_resp, p.linker_scope);
@@ -731,7 +732,8 @@ void Manager::InitPostScript() {
             // vector element not set
             continue;
 
-        SPICY_DEBUG(hilti::rt::fmt("Registering file analyzer %s with Zeek", p.name_analyzer.c_str()));
+        SPICY_DEBUG(hilti::rt::fmt("Registering file analyzer %s (scope 0x%" PRIx64 ") with Zeek",
+                                   p.name_analyzer.c_str(), p.linker_scope.Ref()));
 
         p.parser = find_parser(p.name_analyzer, p.name_parser, p.linker_scope);
 
@@ -766,7 +768,8 @@ void Manager::InitPostScript() {
             // vector element not set
             continue;
 
-        SPICY_DEBUG(hilti::rt::fmt("Registering packet analyzer %s with Zeek", p.name_analyzer.c_str()));
+        SPICY_DEBUG(hilti::rt::fmt("Registering packet analyzer %s (scope 0x%" PRIx64 ") with Zeek",
+                                   p.name_analyzer.c_str(), p.linker_scope.Ref()));
         p.parser = find_parser(p.name_analyzer, p.name_parser, p.linker_scope);
     }
 
@@ -862,7 +865,7 @@ void Manager::searchModules(const std::string& paths) {
 
 detail::Location Manager::makeLocation(const std::string& fname) {
     auto x = _locations.insert(fname);
-    return detail::Location(x.first->c_str(), 0, 0, 0, 0);
+    return {x.first->c_str(), 0, 0};
 }
 
 void Manager::autoDiscoverModules() {
