@@ -1,9 +1,10 @@
 #include "Foo.h"
 
-#include <zeek/file_analysis/File.h>
-#include <zeek/file_analysis/Manager.h>
 #include <algorithm>
 
+#include "zeek/file_analysis/File.h"
+#include "zeek/file_analysis/Manager.h"
+
 #include "events.bif.h"
 
 using namespace btest::plugin::Demo_Foo;
